@@ -91,7 +91,7 @@ mod tests {
         assert!(!statement.cash_assets.is_empty());
         assert!(!statement.deposits_and_withdrawals.is_empty());
 
-        assert!(statement.fees.is_empty());
+        assert!(!statement.fees.is_empty());
         assert!(!statement.idle_cash_interest.is_empty());
         assert!(statement.tax_agent_withholdings.is_empty());
 
@@ -100,7 +100,7 @@ mod tests {
         assert!(!statement.stock_sells.is_empty());
         assert!(!statement.dividends.is_empty());
 
-        assert!(!statement.open_positions.is_empty());
+        assert!(statement.open_positions.is_empty());
         assert!(statement.instrument_names.is_empty());
     }
 }
\ No newline at end of file
